Crate nidus_http

Crate nidus_http 

HTTP routing, controllers, middleware, request, and response helpers.

Re-exports

pub use request::RequestScopeRejection;
pub use request::RequestScoped;

Modules

context
Request context primitives shared by middleware, handlers, and observers.
controller
Controller metadata.
error
HTTP error helpers.
health
Health and readiness registry helpers.
logging
Structured logging helpers built on tracing and tracing-subscriber.
middleware
Tower middleware helpers.
request
Request extractors and helpers.
response
Response helpers.
router
Axum router composition.
server
Application server helpers built on Axum and Tokio.

Structs

HeaderMap
A specialized multimap for header names and values.
Json
JSON Extractor / Response.
Path
Extractor that will get captures from the URL and parse them using serde.
Query
Extractor that deserializes query strings into some type.
Router
The router type for composing handlers and services.
State
Extractor for state.
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).

Traits

IntoResponse
Trait for generating responses.

Type Aliases

Response
Type alias for http::Response whose body type defaults to Body, the most common body type used with axum.