pub struct HealthStatus { /* private fields */ }Expand description
Result of a liveness or readiness check.
Return HealthStatus::up for healthy dependencies and
HealthStatus::down with a safe diagnostic message for unhealthy ones.
Messages are included in health JSON by default and can be suppressed with
HealthRegistry::hide_details.
Implementations
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub fn down(message: impl Into<String>) -> Self
pub fn down(message: impl Into<String>) -> Self
Creates a down health status with a safe diagnostic message.
Keep the message operational and non-sensitive because it is exposed in
response bodies unless the registry uses HealthRegistry::hide_details.