pub fn catch_panic_layer() -> CatchPanicLayerExpand description
Creates a layer that catches panics from the inner service and maps them to a
500 Internal Server Error response.
See CatchPanicLayer for details.
pub fn catch_panic_layer() -> CatchPanicLayerCreates a layer that catches panics from the inner service and maps them to a
500 Internal Server Error response.
See CatchPanicLayer for details.