pub enum RequestScopeRejection {
MissingScope,
ResolutionFailed(NidusError),
}Expand description
Rejection returned when a request-scoped provider cannot be extracted.
Variants
MissingScope
The request did not contain a Nidus request scope.
ResolutionFailed(NidusError)
The request scope failed to resolve the requested provider.