Module router

Module router 

Axum router composition.

Structs

RouteDefinition
A route declaration that can be mounted by a controller.
RouteMetadata
Static route metadata generated by route macros.

Type Aliases

OpenApiSchemaRegistrar
Typed callback that adds one or more schemas into the OpenAPI registry.