RouteMetadata

Struct RouteMetadata 

pub struct RouteMetadata { /* private fields */ }
Static route metadata generated by route macros.

Implementations

Source

impl RouteMetadata

pub const fn new(method: &'static str, path: &'static str) -> Self

Creates route metadata.

pub const fn with_summary( method: &'static str, path: &'static str, summary: &'static str, ) -> Self

Creates route metadata with an OpenAPI summary.

pub const fn with_annotations( method: &'static str, path: &'static str, summary: Option<&'static str>, guards: &'static [&'static str], pipes: &'static [&'static str], validates: bool, ) -> Self

Creates route metadata with all supported static annotations.

pub const fn with_openapi_annotations( method: &'static str, path: &'static str, summary: Option<&'static str>, tags: &'static [&'static str], guards: &'static [&'static str], pipes: &'static [&'static str], validates: bool, ) -> Self

Creates route metadata with all supported static annotations, including OpenAPI tags.

pub const fn with_openapi_schemas( self, request_schema: Option<&'static str>, response_schema: Option<&'static str>, ) -> Self

Adds OpenAPI schema references to route metadata.

pub fn with_openapi_schema_registrars( self, request_schema: Option<OpenApiSchemaRegistrar>, response_schema: Option<OpenApiSchemaRegistrar>, ) -> Self

Adds OpenAPI schema registration callbacks for route metadata.

pub const fn with_openapi_status( self, response_status: Option<StatusCode>, ) -> Self

Adds an OpenAPI success response status to route metadata.

pub const fn method(&self) -> &'static str

Returns the HTTP method.

pub const fn path(&self) -> &'static str

Returns the route path as declared by the user.

pub const fn summary(&self) -> Option<&'static str>

Returns the OpenAPI summary, when declared.

pub const fn tags(&self) -> &'static [&'static str]

Returns OpenAPI tags declared on the route.

pub const fn response_status(&self) -> Option<StatusCode>

Returns the OpenAPI success response status, when declared.

pub const fn request_schema(&self) -> Option<&'static str>

Returns the OpenAPI request schema reference name, when declared.

pub const fn response_schema(&self) -> Option<&'static str>

Returns the OpenAPI response schema reference name, when declared.

pub const fn request_schema_registrar(&self) -> Option<OpenApiSchemaRegistrar>

Returns the OpenAPI request schema registration callback, when declared.

pub const fn response_schema_registrar(&self) -> Option<OpenApiSchemaRegistrar>

Returns the OpenAPI response schema registration callback, when declared.

pub const fn guards(&self) -> &'static [&'static str]

Returns guard type names declared on the route.

pub const fn pipes(&self) -> &'static [&'static str]

Returns pipe type names declared on the route.

pub const fn validates(&self) -> bool

Returns whether validation is enabled for the route.

pub fn full_path(&self, controller_prefix: &str) -> String

Composes this route path with a controller prefix using Nidus path normalization.

pub fn try_full_path( &self, controller_prefix: &str, ) -> Result<String, RoutePathError>

Tries to compose this route path with a controller prefix using Nidus path normalization.